@@ -44,9 +44,10 @@
  *   APP_AUTHZLEVEL
  *
  */
-// dirty hack to run silently on both systems
+// dirty hack to run silently on all systems
 @include_once 'smarty/libs/Smarty.class.php';    // Debian
 @include_once 'smarty/Smarty.class.php';         // Ubuntu
+@include_once 'Smarty/Smarty.class.php';         // RHEL / CentOS
 
 require_once 'SPAF2/ApplicationConfig.php';
 require_once 'SPAF2/DBAccess.php';
