@@ -51,6 +51,7 @@ class Backend
         global $App;
         $this->rest_user = 'benno2';
         $this->rest_pass = $App->getConfig('SHARED_SECRET');
+        $this->rest_ssl_verify = $App->getConfig('REST_SSL_VERIFY');
 
         $this->base_url = $base_url;
         $this->archive  = $archive;
@@ -249,6 +250,15 @@ class Backend
             curl_setopt($curl, CURLOPT_COOKIEJAR, $cookie_file);
             curl_setopt($curl, CURLOPT_COOKIEFILE, $cookie_file);
         }
+        if (preg_match('/^https:/',$request_url)) {
+            if ($this->rest_ssl_verify == 'YES') {
+                curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, true);
+            }
+            else {
+                curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
+            }
+        }
+
         if (($response = curl_exec($curl)) === false) {
             $App->log('[Backend/query] Request error: '.curl_error($curl));
             throw new Exception('ERR_REQUEST');
