@@ -139,15 +139,15 @@ class QueryResult
         return '';
     }
 
-    function numFirst () { return $this->first+1; }
+    function numFirst () { return $this->first; }
 
-    function numLast  () { return $this->last+1; }
+    function numLast  () { return $this->last; }
 
     function jumpPrev () { return $this->first-$this->limit; }
 
     function jumpNext ()
     {
-        if (($this->last+1) >= ($this->found-1)) {  // jump behind end
+        if (($this->last) >= ($this->found-1)) {  // jump behind end
             return $this->jumpEnd();
         }
         return $this->last+1;
@@ -159,7 +159,7 @@ class QueryResult
             return 0;
         }
         $modulo = $this->found % $this->limit;      // jump to last page
-        return $this->found-$modulo;                // in limit raster
+        return $this->found-$modulo+1;              // in limit raster
     }
 
 
