@@ -77,9 +77,6 @@ class UserDA extends Persistence
         $DB = $App->DB;
         $sql = "SELECT * FROM user WHERE id = '$this->id'";
         $res = $DB->query($sql);
-        if (DB::isError($res)) {
-            throw new Exception($res);
-        }
         // read data from query
         $row = $res->fetchRow();
         $this->password = $row['password'];
